@@ -5,10 +5,11 @@ import textwrap
 
 
 class Style:
-    def __init__(self, selector: Selector = None, *, parent:"Style"=None) -> None:
+    def __init__(self, selector: Selector = None, *, parent: "Style" = None) -> None:
         self.selector = selector
         self._rules = {}
-        self.parent = parent
+        self._parent = parent
+        self._children = []
 
     def rule(self, attr: str, value) -> "Style":
         self._rules[attr] = value
@@ -94,7 +95,14 @@ class Style:
 
         return self
 
-    def absolute(self, *, left:int=None, right:int=None, top:int=None, bottom:int=None) -> "Style":
+    def absolute(
+        self,
+        *,
+        left: int = None,
+        right: int = None,
+        top: int = None,
+        bottom: int = None,
+    ) -> "Style":
         self.rule("position", "absolute")
 
         if left is not None:
@@ -108,17 +116,38 @@ class Style:
 
         return self
 
-    def rounded(self, radius:Unit=None):
+    def center(self) -> "Style":
+        return self.rule("text-align", "center")
+
+    def rounded(self, radius: Unit = None):
         if radius is None:
             radius = 0.25
 
         return self.rule("border-radius", Unit.infer(radius))
 
-    def width(self, value):
-        return self.rule("width", Unit.infer(value, on_float=pc))
+    def width(self, value=None, *, min=None, max=None):
+        if value is not None:
+            self.rule("width", Unit.infer(value, on_float=pc))
 
-    def height(self, value):
-        return self.rule("height", Unit.infer(value, on_float=pc))
+        if min is not None:
+            self.rule("min-width", Unit.infer(min, on_float=pc))
+
+        if max is not None:
+            self.rule("max-width", Unit.infer(max, on_float=pc))
+
+        return self
+
+    def height(self, value=None, *, min=None, max=None):
+        if value is not None:
+            self.rule("height", Unit.infer(value, on_float=pc))
+
+        if min is not None:
+            self.rule("min-height", Unit.infer(min, on_float=pc))
+
+        if max is not None:
+            self.rule("max-height", Unit.infer(max, on_float=pc))
+
+        return self
 
     def css(self, inline: bool = False) -> str:
         separator = "" if inline else "\n"
@@ -139,7 +168,9 @@ class Style:
         return self.selector.markup()
 
     def on(self, state) -> "Style":
-        return Style(self.selector.on(state))
+        style = Style(self.selector.on(state))
+        self._children.append(style)
+        return style
 
     def __str__(self):
         return self.markup()
